==> huaweicloudsdkiotda-3.0.5b0-py3-none-any.whl: huaweicloudsdkiotda/v5/model/time_range.py <==
# coding: utf-8

import pprint
import re

import six


class TimeRange(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'start_time': 'str',
        'end_time': 'str',
        'days_of_week': 'str'
    }

    attribute_map = {
        'start_time': 'start_time',
        'end_time': 'end_time',
        'days_of_week': 'days_of_week'
    }

    def __init__(self, start_time=None, end_time=None, days_of_week=None):  # noqa: E501
        """TimeRange - a model defined in huaweicloud sdk"""

        self._start_time = None
        self._end_time = None
        self._days_of_week = None
        self.discriminator = None

        self.start_time = start_time
        self.end_time = end_time
        if days_of_week is not None:
            self.days_of_week = days_of_week

    @property
    def start_time(self):
        """Gets the start_time of this TimeRange.

        规则条件触发的开始时间，格式：HH:mm。

        :return: The start_time of this TimeRange.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this TimeRange.

        规则条件触发的开始时间，格式：HH:mm。

        :param start_time: The start_time of this TimeRange.
        :type: str
        """
        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this TimeRange.

        规则条件触发的结束时间，格式：HH:mm。若结束时间与开始时间一致，则时间为全天。

        :return: The end_time of this TimeRange.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this TimeRange.

        规则条件触发的结束时间，格式：HH:mm。若结束时间与开始时间一致，则时间为全天。

        :param end_time: The end_time of this TimeRange.
        :type: str
        """
        self._end_time = end_time

    @property
    def days_of_week(self):
        """Gets the days_of_week of this TimeRange.

        星期列表，以逗号分隔。1代表周日，2代表周一，依次类推，默认为每天。星期列表中的日期为开始时间的日期。

        :return: The days_of_week of this TimeRange.
        :rtype: str
        """
        return self._days_of_week

    @days_of_week.setter
    def days_of_week(self, days_of_week):
        """Sets the days_of_week of this TimeRange.

        星期列表，以逗号分隔。1代表周日，2代表周一，依次类推，默认为每天。星期列表中的日期为开始时间的日期。

        :param days_of_week: The days_of_week of this TimeRange.
        :type: str
        """
        self._days_of_week = days_of_week

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeRange):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotda-3.0.35rc0-py3-none-any.whl: huaweicloudsdkiotda/v5/model/time_range.py <==
# coding: utf-8

import pprint
import re

import six





class TimeRange:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'start_time': 'str',
        'end_time': 'str',
        'days_of_week': 'str'
    }

    attribute_map = {
        'start_time': 'start_time',
        'end_time': 'end_time',
        'days_of_week': 'days_of_week'
    }

    def __init__(self, start_time=None, end_time=None, days_of_week=None):
        """TimeRange - a model defined in huaweicloud sdk"""
        
        

        self._start_time = None
        self._end_time = None
        self._days_of_week = None
        self.discriminator = None

        self.start_time = start_time
        self.end_time = end_time
        if days_of_week is not None:
            self.days_of_week = days_of_week

    @property
    def start_time(self):
        """Gets the start_time of this TimeRange.

        规则条件触发的开始时间，格式：HH:mm。

        :return: The start_time of this TimeRange.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this TimeRange.

        规则条件触发的开始时间，格式：HH:mm。

        :param start_time: The start_time of this TimeRange.
        :type: str
        """
        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this TimeRange.

        规则条件触发的结束时间，格式：HH:mm。若结束时间与开始时间一致，则时间为全天。

        :return: The end_time of this TimeRange.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this TimeRange.

        规则条件触发的结束时间，格式：HH:mm。若结束时间与开始时间一致，则时间为全天。

        :param end_time: The end_time of this TimeRange.
        :type: str
        """
        self._end_time = end_time

    @property
    def days_of_week(self):
        """Gets the days_of_week of this TimeRange.

        星期列表，以逗号分隔。1代表周日，2代表周一，依次类推，默认为每天。星期列表中的日期为开始时间的日期。

        :return: The days_of_week of this TimeRange.
        :rtype: str
        """
        return self._days_of_week

    @days_of_week.setter
    def days_of_week(self, days_of_week):
        """Sets the days_of_week of this TimeRange.

        星期列表，以逗号分隔。1代表周日，2代表周一，依次类推，默认为每天。星期列表中的日期为开始时间的日期。

        :param days_of_week: The days_of_week of this TimeRange.
        :type: str
        """
        self._days_of_week = days_of_week

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeRange):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
